/*
 * JavaScript containing event callbacks for the widget admin panel.
 */

/**
 * Invoked when the Product drop down is changed - enables or disables the product category drop down based on
 * whether the Random Product option is selected.
 */
function pndl_product_changed(element) {
	div = jQuery(element).closest(".widget-content").find(".pndl_category_selector");
	if (element.selectedIndex == 0) {
		div.removeAttr('disabled');
	} else {
		div.attr('disabled', 'disabled');
	}
}

/**
 * Invoked when the "Show Image" check box is clicked - shows or hides the image settings div. 
 */
function pndl_show_image_clicked(element) {
	// we do not use IDs because we can't work out what they are (especially when new wdigets are dragged in)
	// instead we start from element, navigate up to the widget container, then match the div containing 
	// the image settings marked by our own class
	div = jQuery(element).closest(".widget-content").find(".pndl_image_outer");
	if (element.checked) {
		div.show();
	} else {
		div.hide();
	}
}

/**
 * Invoked when the Image Size drop down is changed - shows or hides the image size div appropriately.
 */
function pndl_image_size_changed(element) {
	div = jQuery(element).closest(".pndl_image_outer").find(".pndl_size_options");
	if (element.selectedIndex == 2) {
		div.show();
	} else {
		div.hide();
	}
}
